@@ -12,9 +12,9 @@ from django.template import Library, Node, TemplateSyntaxError
 from analytical.utils import disable_html, get_required_setting, is_internal_ip
 
 USER_ID_RE = re.compile(r'^\d+$')
-INIT_CODE = """<script type="text/javascript">var _sf_startpt=(new Date()).getTime()</script>"""
+INIT_CODE = """<script>var _sf_startpt=(new Date()).getTime()</script>"""
 SETUP_CODE = """
-    <script type="text/javascript">
+    <script>
       var _sf_async_config=%(config)s;
       (function(){
         function loadChartbeat() {
@@ -55,7 +55,7 @@ def chartbeat_top(parser, token):
 class ChartbeatTopNode(Node):
     def render(self, context):
         if is_internal_ip(context):
-            return disable_html(INIT_CODE, "Chartbeat")
+            return disable_html(INIT_CODE, 'Chartbeat')
         return INIT_CODE
 
 
@@ -76,8 +76,9 @@ def chartbeat_bottom(parser, token):
 
 class ChartbeatBottomNode(Node):
     def __init__(self):
-        self.user_id = get_required_setting('CHARTBEAT_USER_ID', USER_ID_RE,
-                                            "must be (a string containing) a number")
+        self.user_id = get_required_setting(
+            'CHARTBEAT_USER_ID', USER_ID_RE, 'must be (a string containing) a number'
+        )
 
     def render(self, context):
         config = {'uid': self.user_id}
@@ -106,6 +107,7 @@ def _get_domain(context):
             return
         elif getattr(settings, 'CHARTBEAT_AUTO_DOMAIN', True):
             from django.contrib.sites.models import Site
+
             try:
                 return Site.objects.get_current().domain
             except (ImproperlyConfigured, Site.DoesNotExist):  # pylint: disable=E1101
