@@ -10,7 +10,7 @@ from analytical.utils import disable_html, get_required_setting, is_internal_ip
 
 SITE_ID_RE = re.compile(r'[\da-f]+$')
 TRACKING_CODE = """
-    <script type="text/javascript">
+    <script>
       var _gauges = _gauges || [];
       (function() {
         var t   = document.createElement('script');
@@ -46,8 +46,8 @@ def gauges(parser, token):
 class GaugesNode(Node):
     def __init__(self):
         self.site_id = get_required_setting(
-                'GAUGES_SITE_ID', SITE_ID_RE,
-                "must be a string looking like 'XXXXXXX'")
+            'GAUGES_SITE_ID', SITE_ID_RE, "must be a string looking like 'XXXXXXX'"
+        )
 
     def render(self, context):
         html = TRACKING_CODE % {'site_id': self.site_id}
