@@ -41,12 +41,11 @@ def hotjar(parser, token):
 
 
 class HotjarNode(Node):
-
     def __init__(self):
         self.site_id = get_required_setting(
             'HOTJAR_SITE_ID',
             re.compile(r'^\d+$'),
-            "must be (a string containing) a number",
+            'must be (a string containing) a number',
         )
 
     def render(self, context):
