@@ -11,7 +11,7 @@ from analytical.utils import disable_html, get_required_setting, is_internal_ip
 PORTAL_ID_RE = re.compile(r'^\d+$')
 TRACKING_CODE = """
     <!-- Start of Async HubSpot Analytics Code -->
-      <script type="text/javascript">
+      <script>
         (function(d,s,i,r) {
           if (d.getElementById(i)){return;}
           var n=d.createElement(s),e=d.getElementsByTagName(s)[0];
@@ -41,8 +41,9 @@ def hubspot(parser, token):
 
 class HubSpotNode(Node):
     def __init__(self):
-        self.portal_id = get_required_setting('HUBSPOT_PORTAL_ID', PORTAL_ID_RE,
-                                              "must be a (string containing a) number")
+        self.portal_id = get_required_setting(
+            'HUBSPOT_PORTAL_ID', PORTAL_ID_RE, 'must be a (string containing a) number'
+        )
 
     def render(self, context):
         html = TRACKING_CODE % {'portal_id': self.portal_id}
