@@ -11,8 +11,8 @@ from analytical.utils import get_identity, get_required_setting
 ACCOUNT_NUMBER_RE = re.compile(r'^\d+$')
 SITE_CODE_RE = re.compile(r'^[\w]+$')
 SETUP_CODE = """
-    <script type="text/javascript">var _kiq = _kiq || []; %(commands)s</script>
-    <script type="text/javascript" src="//s3.amazonaws.com/ki.js/%(account_number)s/%(site_code)s.js" async="true"></script>
+    <script>var _kiq = _kiq || []; %(commands)s</script>
+    <script src="//s3.amazonaws.com/ki.js/%(account_number)s/%(site_code)s.js" async="true"></script>
 """  # noqa
 IDENTIFY_CODE = "_kiq.push(['identify', '%s']);"
 SHOW_SURVEY_CODE = "_kiq.push(['showSurvey', %s]);"
@@ -41,11 +41,15 @@ def kiss_insights(parser, token):
 class KissInsightsNode(Node):
     def __init__(self):
         self.account_number = get_required_setting(
-            'KISS_INSIGHTS_ACCOUNT_NUMBER', ACCOUNT_NUMBER_RE,
-            "must be (a string containing) a number")
+            'KISS_INSIGHTS_ACCOUNT_NUMBER',
+            ACCOUNT_NUMBER_RE,
+            'must be (a string containing) a number',
+        )
         self.site_code = get_required_setting(
-            'KISS_INSIGHTS_SITE_CODE', SITE_CODE_RE,
-            "must be a string containing three characters")
+            'KISS_INSIGHTS_SITE_CODE',
+            SITE_CODE_RE,
+            'must be a string containing three characters',
+        )
 
     def render(self, context):
         commands = []
@@ -59,7 +63,7 @@ class KissInsightsNode(Node):
         html = SETUP_CODE % {
             'account_number': self.account_number,
             'site_code': self.site_code,
-            'commands': " ".join(commands),
+            'commands': ' '.join(commands),
         }
         return html
 
