@@ -33,8 +33,10 @@ def optimizely(parser, token):
 class OptimizelyNode(Node):
     def __init__(self):
         self.account_number = get_required_setting(
-                'OPTIMIZELY_ACCOUNT_NUMBER', ACCOUNT_NUMBER_RE,
-                "must be a string looking like 'XXXXXXX'")
+            'OPTIMIZELY_ACCOUNT_NUMBER',
+            ACCOUNT_NUMBER_RE,
+            "must be a string looking like 'XXXXXXX'",
+        )
 
     def render(self, context):
         html = SETUP_CODE % {'account_number': self.account_number}
