@@ -10,7 +10,7 @@ from analytical.utils import disable_html, get_required_setting, is_internal_ip
 
 COUNTER_ID_RE = re.compile(r'^\d{7}$')
 COUNTER_CODE = """
-    <script type="text/javascript">
+    <script>
     var _tmr = window._tmr || (window._tmr = []);
     _tmr.push({id: "%(counter_id)s", type: "pageView", start: (new Date()).getTime()});
     (function (d, w, id) {
@@ -48,8 +48,10 @@ def rating_mailru(parser, token):
 class RatingMailruNode(Node):
     def __init__(self):
         self.counter_id = get_required_setting(
-            'RATING_MAILRU_COUNTER_ID', COUNTER_ID_RE,
-            "must be (a string containing) a number'")
+            'RATING_MAILRU_COUNTER_ID',
+            COUNTER_ID_RE,
+            "must be (a string containing) a number'",
+        )
 
     def render(self, context):
         html = COUNTER_CODE % {
