@@ -59,6 +59,36 @@ class GoogleAnalyticsTagTestCase(TagTestCase):
         r = GoogleAnalyticsGTagNode().render(Context({'user': User(username='test')}))
         assert "gtag('set', {'user_id': 'test'});" in r
 
+    def test_identity_context_specific_provider(self):
+        """
+        The user_id variable must be set according to
+        google_analytics_gtag_identity variable in the context.
+        """
+        r = GoogleAnalyticsGTagNode().render(
+            Context(
+                {
+                    'google_analytics_gtag_identity': 'foo_gtag_identity',
+                    'analytical_identity': 'bar_analytical_identity',
+                    'user': User(username='test'),
+                }
+            )
+        )
+        assert "gtag('set', {'user_id': 'foo_gtag_identity'});" in r
+
+    def test_identity_context_general(self):
+        """
+        The user_id variable must be set according to analytical_identity variable in the context.
+        """
+        r = GoogleAnalyticsGTagNode().render(
+            Context(
+                {
+                    'analytical_identity': 'bar_analytical_identity',
+                    'user': User(username='test'),
+                }
+            )
+        )
+        assert "gtag('set', {'user_id': 'bar_analytical_identity'});" in r
+
     @override_settings(GOOGLE_ANALYTICS_GTAG_PROPERTY_ID='G-12345678')
     def test_tag_with_measurement_id(self):
         r = self.render_tag('google_analytics_gtag', 'google_analytics_gtag')
