@@ -15,7 +15,7 @@ from analytical.templatetags.intercom import IntercomNode, intercom_user_hash
 from analytical.utils import AnalyticalException
 
 
-@override_settings(INTERCOM_APP_ID="abc123xyz")
+@override_settings(INTERCOM_APP_ID='abc123xyz')
 class IntercomTagTestCase(TagTestCase):
     """
     Tests for the ``intercom`` template tag.
@@ -23,7 +23,9 @@ class IntercomTagTestCase(TagTestCase):
 
     def test_tag(self):
         rendered_tag = self.render_tag('intercom', 'intercom')
-        assert rendered_tag.strip().startswith('<script id="IntercomSettingsScriptTag">')
+        assert rendered_tag.strip().startswith(
+            '<script id="IntercomSettingsScriptTag">'
+        )
 
     def test_node(self):
         now = datetime.datetime(2014, 4, 9, 15, 15, 0)
@@ -31,17 +33,21 @@ class IntercomTagTestCase(TagTestCase):
             username='test',
             first_name='Firstname',
             last_name='Lastname',
-            email="test@example.com",
+            email='test@example.com',
             date_joined=now,
         )
         rendered_tag = IntercomNode().render(Context({'user': user}))
         # Because the json isn't predictably ordered, we can't just test the whole thing verbatim.
-        assert rendered_tag == """
+        assert (
+            rendered_tag
+            == """
 <script id="IntercomSettingsScriptTag">
   window.intercomSettings = {"app_id": "abc123xyz", "created_at": 1397074500, "email": "test@example.com", "name": "Firstname Lastname", "user_id": %(user_id)s};
 </script>
 <script>(function(){var w=window;var ic=w.Intercom;if(typeof ic==="function"){ic('reattach_activator');ic('update',intercomSettings);}else{var d=document;var i=function(){i.c(arguments)};i.q=[];i.c=function(args){i.q.push(args)};w.Intercom=i;function l(){var s=d.createElement('script');s.type='text/javascript';s.async=true;s.src='https://static.intercomcdn.com/intercom.v1.js';var x=d.getElementsByTagName('script')[0];x.parentNode.insertBefore(s,x);}if(w.attachEvent){w.attachEvent('onload',l);}else{w.addEventListener('load',l,false);}}})()</script>
-""" % {'user_id': user.pk}  # noqa
+"""
+            % {'user_id': user.pk}
+        )  # noqa
 
     @override_settings(INTERCOM_APP_ID=None)
     def test_no_account_number(self):
@@ -59,32 +65,34 @@ class IntercomTagTestCase(TagTestCase):
             username='test',
             first_name='Firstname',
             last_name='Lastname',
-            email="test@example.com",
+            email='test@example.com',
             date_joined=now,
         )
-        r = IntercomNode().render(Context({
-            'user': user,
-        }))
+        r = IntercomNode().render(Context({'user': user}))
         assert (
             'window.intercomSettings = {"app_id": "abc123xyz", "created_at": 1397074500, '
             f'"email": "test@example.com", "name": "Firstname Lastname", "user_id": {user.pk}}};'
         ) in r
 
     def test_custom(self):
-        r = IntercomNode().render(Context({
-                'intercom_var1': 'val1',
-                'intercom_var2': 'val2'
-        }))
+        r = IntercomNode().render(
+            Context({'intercom_var1': 'val1', 'intercom_var2': 'val2'})
+        )
         assert 'var1": "val1", "var2": "val2"' in r
 
     def test_identify_name_and_email(self):
-        r = IntercomNode().render(Context({
-                'user': User(
-                    username='test',
-                    first_name='Firstname',
-                    last_name='Lastname',
-                    email="test@example.com"),
-        }))
+        r = IntercomNode().render(
+            Context(
+                {
+                    'user': User(
+                        username='test',
+                        first_name='Firstname',
+                        last_name='Lastname',
+                        email='test@example.com',
+                    ),
+                }
+            )
+        )
         assert '"email": "test@example.com", "name": "Firstname Lastname"' in r
 
     def test_identify_username_no_email(self):
@@ -92,17 +100,25 @@ class IntercomTagTestCase(TagTestCase):
         assert '"name": "test"' in r, r
 
     def test_no_identify_when_explicit_name(self):
-        r = IntercomNode().render(Context({
-            'intercom_name': 'explicit',
-            'user': User(username='implicit'),
-        }))
+        r = IntercomNode().render(
+            Context(
+                {
+                    'intercom_name': 'explicit',
+                    'user': User(username='implicit'),
+                }
+            )
+        )
         assert '"name": "explicit"' in r, r
 
     def test_no_identify_when_explicit_email(self):
-        r = IntercomNode().render(Context({
-            'intercom_email': 'explicit',
-            'user': User(username='implicit'),
-        }))
+        r = IntercomNode().render(
+            Context(
+                {
+                    'intercom_email': 'explicit',
+                    'user': User(username='implicit'),
+                }
+            )
+        )
         assert '"email": "explicit"' in r, r
 
     @override_settings(INTERCOM_HMAC_SECRET_KEY='secret')
@@ -135,10 +151,14 @@ class IntercomTagTestCase(TagTestCase):
         """
         'user_hash' of context-provided `user_id`.
         """
-        attrs = IntercomNode()._get_custom_attrs(Context({
-            'intercom_email': 'test@example.com',
-            'intercom_user_id': '5',
-        }))
+        attrs = IntercomNode()._get_custom_attrs(
+            Context(
+                {
+                    'intercom_email': 'test@example.com',
+                    'intercom_user_id': '5',
+                }
+            )
+        )
         assert attrs == {
             'created_at': None,
             'email': 'test@example.com',
@@ -152,9 +172,13 @@ class IntercomTagTestCase(TagTestCase):
         """
         'user_hash' of context-provided `email`.
         """
-        attrs = IntercomNode()._get_custom_attrs(Context({
-            'intercom_email': 'test@example.com',
-        }))
+        attrs = IntercomNode()._get_custom_attrs(
+            Context(
+                {
+                    'intercom_email': 'test@example.com',
+                }
+            )
+        )
         assert attrs == {
             'created_at': None,
             'email': 'test@example.com',
