@@ -38,10 +38,17 @@ class OlarkTestCase(TagTestCase):
 
     @override_settings(ANALYTICAL_AUTO_IDENTIFY=True)
     def test_identify(self):
-        r = OlarkNode().render(Context({
-            'user': User(username='test', first_name='Test', last_name='User'),
-        }))
-        assert "olark('api.chat.updateVisitorNickname', {snippet: 'Test User (test)'});" in r
+        r = OlarkNode().render(
+            Context(
+                {
+                    'user': User(username='test', first_name='Test', last_name='User'),
+                }
+            )
+        )
+        assert (
+            "olark('api.chat.updateVisitorNickname', {snippet: 'Test User (test)'});"
+            in r
+        )
 
     @override_settings(ANALYTICAL_AUTO_IDENTIFY=True)
     def test_identify_anonymous_user(self):
@@ -58,37 +65,41 @@ class OlarkTestCase(TagTestCase):
         '{snippet: "teststatus"});' in r
 
     def test_status_string_list(self):
-        r = OlarkNode().render(Context({
-            'olark_status': ['teststatus1', 'teststatus2'],
-        }))
+        r = OlarkNode().render(
+            Context(
+                {
+                    'olark_status': ['teststatus1', 'teststatus2'],
+                }
+            )
+        )
         assert "olark('api.chat.updateVisitorStatus', "
         '{snippet: ["teststatus1", "teststatus2"]});' in r
 
     def test_messages(self):
         messages = [
-            "welcome_title",
-            "chatting_title",
-            "unavailable_title",
-            "busy_title",
-            "away_message",
-            "loading_title",
-            "welcome_message",
-            "busy_message",
-            "chat_input_text",
-            "name_input_text",
-            "email_input_text",
-            "offline_note_message",
-            "send_button_text",
-            "offline_note_thankyou_text",
-            "offline_note_error_text",
-            "offline_note_sending_text",
-            "operator_is_typing_text",
-            "operator_has_stopped_typing_text",
-            "introduction_error_text",
-            "introduction_messages",
-            "introduction_submit_button_text",
+            'welcome_title',
+            'chatting_title',
+            'unavailable_title',
+            'busy_title',
+            'away_message',
+            'loading_title',
+            'welcome_message',
+            'busy_message',
+            'chat_input_text',
+            'name_input_text',
+            'email_input_text',
+            'offline_note_message',
+            'send_button_text',
+            'offline_note_thankyou_text',
+            'offline_note_error_text',
+            'offline_note_sending_text',
+            'operator_is_typing_text',
+            'operator_has_stopped_typing_text',
+            'introduction_error_text',
+            'introduction_messages',
+            'introduction_submit_button_text',
         ]
         vars = {f'olark_{m}': m for m in messages}
         r = OlarkNode().render(Context(vars))
         for m in messages:
-            assert f"olark.configure('locale.{m}', \"{m}\");" in r
+            assert f'olark.configure(\'locale.{m}\', "{m}");' in r
