@@ -2,7 +2,6 @@
 Tests for the Yandex.Metrica template tags and filters.
 """
 
-
 import pytest
 from django.http import HttpRequest
 from django.template import Context
@@ -21,11 +20,11 @@ class YandexMetricaTagTestCase(TagTestCase):
 
     def test_tag(self):
         r = self.render_tag('yandex_metrica', 'yandex_metrica')
-        assert "w.yaCounter12345678 = new Ya.Metrika" in r
+        assert 'w.yaCounter12345678 = new Ya.Metrika' in r
 
     def test_node(self):
         r = YandexMetricaNode().render(Context({}))
-        assert "w.yaCounter12345678 = new Ya.Metrika" in r
+        assert 'w.yaCounter12345678 = new Ya.Metrika' in r
 
     @override_settings(YANDEX_METRICA_COUNTER_ID=None)
     def test_no_site_id(self):
